\name{miclust}
\alias{miclust}
\alias{print.miclust}
\alias{plot.miclust}

\title{Multiple imputation in cluster analysis.}

\description{This function implements cluster analysis with selection of the final number of clusters and an optional variable selection procedure. The function is designed to integrate the results of multiple imputed datasets while accounting for the uncertainty that the imputations introduce in the final results. In addition, the function can also be used for a cluster analysis of the complete cases of a single database. See `References' for further details about the clustering algorithm.}

\usage{
miclust(data, method = "kmeans", search = "none", ks = 2:3, maxVars = NULL,
        usedImp = "all", distance = "manhattan", centPos = "colMeans", seed = 4321,
        initCl = "hc")

\method{print}{miclust}(x, ...)
\method{plot}{miclust}(x, k = NULL, ...)
}

\arguments{
  \item{data}{object of class \code{miData} obtained with the function \code{getData}.}
  \item{method}{clustering method. Currently only \code{"kmeans"} is accepted.}
  \item{search}{search algorithm for the selection variable procedure: \code{"backward"}, \code{"forward"} or \code{"none"}. If \code{"none"} (default), no variable selection is performed.}
  \item{ks}{the values of the explored number of clusters. Default is exploring 2 and 3 clusters.}
  \item{maxVars}{if \code{method} is \code{"forward"}, the maximum number of variables to be selected.}
  \item{usedImp}{imputed datasets included in the analysis. Default is \code{"all"}.}
  \item{distance}{two metrics are allowed to compute distances: \code{"manhattan"} (default) and \code{"euclidean"}.}
  \item{centPos}{position computation of the cluster centroid. If \code{"colMeans"} (default) the position of the centroid is computed by the mean. If \code{"colMedians"}, by the median.}
  \item{seed}{the random number seed. The same seed is used in all the imputations in order to avoid an increase of uncertainty due to the clustering algorithm.}
  \item{initCl}{starting values for the clustering algorithm. If \code{"rand"}, they are randomly selected; if \code{"hc"}, they are computed via  hierarchical clustering. See `Details'.}
  \item{x}{object of class \code{miclust}.}
  \item{k}{number of clusters for the final within-cluster summary. Default value is the optimal number of clusters.}
  \item{...}{further arguments for print or plot functions.}
}
\details{The optimal number of clusters and the final set of variables are selected according to CritCF. CritCF is defined as [(1 + 1/(2*m))*(1 + W/B)]^[- (1 + log_2(k+1))/(1 + log_2(m + 1))] where m is the number of variables, k is the number of clusters, and W and B are the within- and between-cluster inertias. Higher values of CritCF are preferred (Breaban, 2011). See `References' for further details about the clustering algorithm.

For computational reasons, option \code{"rand"} is suggested instead \code{"hc"} for high dimensional \code{data}.}
\value{
  \item{clustering}{a list of lists containing the results of the clustering algorithm for each analyzed dataset and for each analyzed number of clusters. Includes information about selected variables and the cluster vector.}
  \item{completeCasesPerc}{if \code{data} contains a single data frame, percentage of complete cases in \code{data}.}
  \item{data}{input \code{data}.}
  \item{ks}{the values of the explored number of clusters.}
  \item{M}{number of imputed datasets provided in \code{data}.}
  \item{usedImp}{if \code{data} is a list, number of imputed datasets used in the clustering procedure. When summarizing results with the \code{summary} function, all available imputations are used.}
  \item{kfin}{optimal number of clusters.}
  \item{CritCF}{if \code{data} contains a single data frame, \code{CritCF} contains the optimal (maximum) value of CritCF (see `Details') and the number of selected variables in the reduction procedure for each explored number of clusters. If \code{data} is a list, \code{CritCF} contains the optimal value of CritCF for each imputed dataset and for each explored value of the number of clusters.}
  \item{NumberOfSelectedVars}{number of selected variables.}
  \item{selectedkdistribution}{if \code{data} is a list, frequency of selection of each analyzed number of clusters.}
  \item{method}{input \code{method}.}
  \item{search}{input \code{search}.}
  \item{maxVars}{input \code{maxVars}.}
  \item{distance}{input \code{distance}.}
  \item{centPos}{input \code{centPos}.}
  \item{selMetricCent}{an object of class \code{kccaFamily} needed by the \code{summary} function.}
  \item{initCl}{input \code{initCl}.}
}
\references{Basagana X, Barrera-Gomez J, Benet M, Anto JM, Garcia-Aymerich J. A framework for multiple imputation in cluster analysis. American Journal of Epidemiology. 2013;177(7):718-25.

Breaban M, Luchian H. A unifying criterion for unsupervised clustering and feature selection. Pattern Recognition 2001;44(4):854-65.
}
\author{Jose Barrera-Gomez and Xavier Basagana.}

\seealso{
\code{\link{getData}} for data preparation before using \code{miclust}.
}
\examples{
data(minhanes)
help(minhanes)

# Example 1: Multiple imputation clustering process with backward variable selection:

# Data preparation:

minhanes1 <- getData(data = minhanes)

# Using only the imputations 1 to 10 for the clustering process and exploring 2 vs. 3 clusters:

minhanes1clust <- miclust(data = minhanes1, search = "backward", ks = 2:3, usedImp = 1:10, seed = 4321)

minhanes1clust
minhanes1clust$kfin  # Optimal number of clusters
plot(minhanes1clust)

# Default summary for the optimal number of clusters:
summary(minhanes1clust)

# Summary forcing 3 clusters:
summary(minhanes1clust, k = 3)

# Example 2: The same analysis without variable selection:

minhanes2clust <- miclust(data = minhanes1, ks = 2:3, usedImp = 1:10, seed = 4321)

minhanes2clust
plot(minhanes2clust)
summary(minhanes2clust)

# Example 3: Complete case clustering process with backward variable selection:

nhanes0 <- getData(data = minhanes[[1]])

nhanes2clust <- miclust(data = nhanes0, search = "backward", ks = 2:3, seed = 4321)

nhanes2clust

# nothing to plot for a single dataset analysis:
plot(nhanes2clust)

summary(nhanes2clust)


# Example 4: Complete case clustering process without variable selection:


nhanes3clust <- miclust(data = nhanes0, ks = 2:3, seed = 4321)

nhanes3clust
summary(nhanes3clust)
}